/*! \file config_rules.h
	\brief Configuration rules for the YAVTI project

	If a rule is broken a compile \#error occurs with an appropriate message
*/
/*
	MRU 110912
	110912 Removed rules for SW_OSD, MAX7456OSD and DOGMDISPLAY
	110113	Added tests for TICKSPERSEC and TIMERFREQ
*/
#include "SIMRCV.h"
#include "config.h"
#ifndef _CONFIG_RULES_H_
	#define _CONFIG_RULES_H_

/* Do not change the following part, it tests the config */

/*! Define at least one of GPS and LWTIME */
#if (!defined GPS) && (!defined LWTIME)
/*! Define at least one of GPS and LWTIME */
	 #error Define one or both of GPS or LWTIME
#endif

#ifdef HARDWARE_SVEN_DEFS
  #ifdef VTIDEVICE_MAX7456OSD
	  #error No MAX7456 in Sven hardware
  #endif
#endif

#ifdef HARDWARE_SVEN_DEFS
  #ifdef DOGMDISPLAY
  	#error No DOGMDISPLAY in Sven hardware
	#endif
#endif

#ifndef HARDWARE_SVEN_DEFS
	#define INIT_MUXS0			/* These only in Sven's HW */
	#define INIT_OE
#endif /* !SVEN_DEFS */

#ifdef VTIDEVICE_NO_OSD
	#define INIT_VSYNC			/* Not needed if no VTI */
	#define INIT_CV
#endif
#ifndef HARDWARE_SVEN_DEFS
  #ifdef VTIDEVICE_SW_OSD
	#error Software OSD only available in Sven''s hardware
#endif
#endif

/* Use SPI for SW_OSD, MAX7456 and DOGM display */
#ifndef VTIDEVICE_NO_OSD
	#define SPI_DEV
#endif
#ifdef DOGMDISPLAY
  #define SPI_DEV
#endif
/* GPS must have RS232 */
#ifdef GPS
	#ifdef PGMFUNCTION_RECEIVER
		#define RX_RS232
	#endif
	#ifdef PGMFUNCTION_SIMULATOR
		#define TX_RS232
	#endif
#endif
/*! Test if TICKSPERSEC whole divisible by 1000 */
#ifdef TICKSPERSEC
	#if ((1000 % TICKSPERSEC) != 0)
/*! \brief ERROR Check the timer frequency, TICKSPERSEC */
		#define TIMERERROR
		#error TICKSPERSEC must be a submultiple of 1000
	#endif
/*! TIMERFREQ must be a submultiple of TICKSPERSEC */
	#if ((TICKSPERSEC % TIMERFREQ) != 0)
/*! Error, TIMERFREQ is not a submultiple of TICKSPERSEC */
		#error TIMERFREQ must be a submultiple of TICKSPERSEC
	#endif
#endif /* TICKSPERSEC */

#if (defined LW_RCV) && (defined LW_SIM)
	#error Define only one or none of LW_RCV and LW_SIM
#endif
/*!  Must define at least one LW transmitter */
#if (!defined DCF77) && (!defined MSF) && (!defined WWVB) && (!defined JJY)
/*! \brief ERROR, must define at least one LW transmitter */
	#define ERRORLWTRANS
	#error Define at least one LW transmitter
#endif /* !DCF77 && !MSF && !WWVB && !JJY */

/* If RXPOLL is defined:
	As experiment run RX without interrupt to reduce jitter in the SW_OSD
	This changes the USART initialisation and runs the RX at base level
	as a task
*/
#ifdef PGMFUNCTION_SIMULATOR
	#undef RXPOLL			/* Never use RXPOLL for SIMULATOR */
#endif

	#ifdef VTIDEVICE_SW_OSD
		#define RXPOLL
	#else
		#undef RXPOLL
	#endif

#endif /* _CONFIG_RULES_H_ */
